@@ -3,7 +3,7 @@
 ##
 ##    Functions for generating random point patterns
 ##
-##    $Revision: 4.116 $   $Date: 2023/07/08 03:28:28 $
+##    $Revision: 4.118 $   $Date: 2024/02/04 08:04:51 $
 ##
 ##    runifpoint()      n i.i.d. uniform random points ("binomial process")
 ##    runifdisc()       special case of disc (faster)
@@ -414,15 +414,17 @@ rpoispp <- function(lambda, lmax=NULL, win = owin(), ...,
       } else {
         ## default 
         win <- rescue.rectangle(as.owin(lambda))
-        if(warnwin)
-          warning("Argument win ignored", call.=FALSE)
+        if(win.given && warnwin)
+          warning(paste("Argument", sQuote("win"), "ignored in rpoispp"),
+                  call.=FALSE)
       }
     }
   }
   
-  if(is.numeric(lambda)) 
+  if(is.numeric(lambda)) {
     ## uniform Poisson
     return(runifpoispp(lambda, win, nsim=nsim, drop=drop))
+  }
 
   ## inhomogeneous Poisson
   ## perform thinning of uniform Poisson
@@ -738,7 +740,7 @@ rPoissonClusterEngine <- function(kappa, expand=rmax, rcluster, win, ...,
   ## Generate parents in dilated window
   win <- as.owin(win)
   frame <- boundingbox(win)
-  dilated <- owin(frame$xrange + c(-expand, expand),
+  dilated <- owinInternalRect(frame$xrange + c(-expand, expand),
                   frame$yrange + c(-expand, expand))
 
   if(is.im(kappa) && !is.subset.owin(dilated, as.owin(kappa)))
